<?php 
/*
 * @package component borggique for Joomla! 3.x
 * @version $Id: com_borggique 1.0.0 2017-4-10 23:26:33Z $
 * @author Kian William Nowrouzian
 * @copyright (C) 2016- Kian William Nowrouzian
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 
 This file is part of borggique.
    borggique is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    borggique is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with borggique.  If not, see <http://www.gnu.org/licenses/>.
 
*/ 
?>


<?php 
\defined('_JEXEC') or die;


use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Categories\CategoryFactoryInterface;
use Joomla\CMS\Categories\CategoryInterface;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Menu\AbstractMenu;
use Joomla\Database\DatabaseInterface;
use Joomla\Database\ParameterType;

/**
 * Routing class from com_contact
 *
 * @since  3.3
 */
class BorggiqueRouter extends RouterView
{
	/**
	 * Flag to remove IDs
	 *
	 * @var    boolean
	 */
	protected $noIDs = false;

	/**
	 * The category factory
	 *
	 * @var CategoryFactoryInterface
	 *
	 * @since  4.0.0
	 */
	private $categoryFactory;

	/**
	 * The category cache
	 *
	 * @var  array
	 *
	 * @since  4.0.0
	 */
	private $categoryCache = [];

	/**
	 * The db
	 *
	 * @var DatabaseInterface
	 *
	 * @since  4.0.0
	 */
	private $db;

	/**
	 * Content Component router constructor
	 *
	 * @param   SiteApplication           $app              The application object
	 * @param   AbstractMenu              $menu             The menu object to work with
	 * @param   CategoryFactoryInterface  $categoryFactory  The category object
	 * @param   DatabaseInterface         $db               The database object
	 */
	//public function __construct(SiteApplication $app, AbstractMenu $menu, CategoryFactoryInterface $categoryFactory, DatabaseInterface $db)
	public function __construct($app=null, $menu=null)
	{
		
		
		//$this->db              = $db;

		$params = ComponentHelper::getParams('com_borggique');
		$this->noIDs = (bool) $params->get('sef_ids');
		
	
		
				
		$borgs = new RouterViewConfiguration('borggique');
		$borgs->setKey('title');
		$this->registerView($borgs);
		
		
		parent::__construct($app, $menu);

		$this->attachRule(new MenuRules($this));
		$this->attachRule(new StandardRules($this));
		$this->attachRule(new NomenuRules($this));
	}

	
	
	public function getBorggiqueSegment($title,  $query)
	{	
		//return array('format'=> 'json', 'title'=>$query['title']);

				return array('format'=> 'json', 'title'=>$title);

	}
	
	public function getBorggiqueTitle($segment, $query)
	{
		return (int) $segment;
	}


    public function parse(&$segments){
		return parent::parse($segments);
	}

    public function build(&$query) {
		return parent::build($query);
	}


	
	
}

function BorggiqueBuildRoute(&$query) {

	$app = Factory::getApplication();
	$router = new BorggiqueRouter($app, $app->getMenu());
	return $router->build($query);
}

function BorggiqueParseRoute($segments) {

	$app = Factory::getApplication();
	$router = new BorggiqueRouter($app, $app->getMenu());
	return $router->parse($segments);
}




